@@ -1,5 +1,6 @@
 import numpy as np
 import math
+from scipy import stats
 
 def teg_nchoosek(x, y):
     try:
@@ -19,12 +20,15 @@ def teg_incomplete_beta(x, a, b):
 
 def teg_cdf_f(F, df_model, df_error):
     x = df_model * F / (df_model * F + df_error)
-    Ix = teg_incomplete_beta(x, df_model/2, df_error/2)
-    p = 1 - Ix
-    return p
+    if F < 1:
+        Ix = teg_incomplete_beta(x, df_model/2, df_error/2)
+    else:
+        Ix = 1 - teg_incomplete_beta(1 - x, df_error / 2, df_model / 2)
+    return Ix
 
 def get_F_p(F, df_model, df_error):
     p = 1 - teg_cdf_f(F, df_model, df_error)
+    # p = 1 - stats.f.cdf(F, df_model, df_error)
     return p
 
 def sim_data(nObs, nPred, fix_coeffs={}, fix_intercept=0):
